/*
 * Copyright (C) 2023, KylinSoft Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

import QtQml 2.12
import QtQuick 2.12
import QtQuick.Layouts 1.12
import QtQuick.Controls 2.5

import AppControls2 1.0 as AppControls2
import org.ukui.menu.core 1.0
import org.ukui.menu.utils 1.0

Item {
    ColumnLayout {
        anchors.fill: parent
        anchors.topMargin: 5
        spacing: 0

        Row {
            Layout.alignment: Qt.AlignBottom
            Layout.fillWidth: true
            Layout.preferredHeight: 40

            AppControls2.StyleBackground {
                width: 32
                height: 32
                paletteRole: Palette.Base
                useStyleTransparent: false
                alpha: powerButtonArea.containsPress ? 0.85 : powerButtonArea.containsMouse ? 0.65 : 0
                radius: height / 2
                borderColor: Palette.Highlight
                border.width: powerButtonArea.activeFocus ? 2 : 0
                PowerButton {
                    id: powerButtonBase
                }

                Image {
                    anchors.centerIn: parent
                    width: Math.floor(parent.width / 2)
                    height: width
                    source: powerButtonBase.icon
                }

                MouseArea {
                    id: powerButtonArea
                    anchors.fill: parent
                    hoverEnabled: true
                    ToolTip.visible: containsMouse
                    ToolTip.text: powerButtonBase.toolTip
                    acceptedButtons: Qt.LeftButton | Qt.RightButton
                    property int spacingFromMenu: 5

                    activeFocusOnTab: true
                    Keys.onPressed: {
                        if (event.key === Qt.Key_Enter || event.key === Qt.Key_Return) {
                            powerButtonBase.clicked(true, 0, 0, mainWindow.isFullScreen);
                        }
                    }

                    onClicked: {
                        var buttonPosition = powerButtonArea.mapToGlobal(width, height);
                        powerButtonBase.clicked(mouse.button === Qt.LeftButton, buttonPosition.x + spacingFromMenu, buttonPosition.y + spacingFromMenu, mainWindow.isFullScreen);
                    }
                }
            }
        }
    }
}