/*
 * Copyright (C) 2022, KylinSoft Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

#ifndef UKUI_MENU_COMMONS_H
#define UKUI_MENU_COMMONS_H

#include "data-entity.h"

namespace UkuiMenu {

// 标签项
class LabelItem
{
    Q_GADGET
public:
    enum PropertyName {
        IsDisable = 0,
        Index,
        Id,
        DisplayName
    };
    LabelItem() = default;
    explicit LabelItem(bool disable, int index, QString id, QString displayName);

    friend inline bool operator==(const LabelItem& a, const LabelItem& b) {
        return QString::compare(a.id(), b.id(), Qt::CaseInsensitive);
    }

    bool isDisable() const;
    void setDisable(bool disable);

    int index() const;
    void setIndex(int index);

    const QString &id() const;
    void setId(const QString &id);

    const QString &displayName() const;
    void setDisplayName(const QString &name);

private:
    bool    m_disable{true};
    int     m_index{0};
    QString m_id;
    QString m_displayName;
};

class Display {
    Q_GADGET
public:
    enum Type {
        IconOnly,
        TextOnly,
        TextBesideIcon,
        TextUnderIcon
    };

    Q_ENUM(Type)
};

} // UkuiMenu

#endif //UKUI_MENU_COMMONS_H
