/*
 * Copyright (C) 2022, KylinSoft Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

#ifndef UKUI_MENU_MENU_EXTENSION_H
#define UKUI_MENU_MENU_EXTENSION_H

#include <QObject>
#include <QHash>
#include <QString>
#include <QVector>
#include <QVariant>
#include <QAbstractListModel>

#include "menu-extension-iface.h"

namespace UkuiMenu {

class ExtensionModel;

class MenuExtension : public QObject
{
    Q_OBJECT
public:
    static MenuExtension *instance();
    void registerExtension(MenuExtensionIFace *extension);
    Q_INVOKABLE ExtensionModel *extensionModel();

private:
    MenuExtension();
    void loadExtensions();
    void initModel();

private:
    ExtensionModel *m_model{nullptr};
    QMap<QString, MenuExtensionIFace*> m_extensions;
};

class ExtensionModel : public QAbstractListModel
{
    Q_OBJECT
public:
    enum Name {
        Name,
        Url,
        Data
    };

    explicit ExtensionModel(const QVector<MenuExtensionIFace*> &extensions, QObject *parent = nullptr);

    int rowCount(const QModelIndex &parent) const override;
    QVariant data(const QModelIndex &index, int role) const override;
    QHash<int, QByteArray> roleNames() const override;

    Q_INVOKABLE void send(int index, QVariantMap data);

private:
    void extensionDataChanged(int index);

private:
    QHash<int, QByteArray> m_roleNames;
    QVector<MenuExtensionIFace*> m_extensions;
};

} // UkuiMenu

#endif //UKUI_MENU_MENU_EXTENSION_H
