/*
 * Copyright (C) 2022, KylinSoft Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: hxf <hewenfei@kylinos.cn>
 *
 */

#ifndef UKUI_SIDEBAR_THEME_PALETTE_H
#define UKUI_SIDEBAR_THEME_PALETTE_H

#include <QObject>
#include <QPalette>
#include "settings.h"

namespace UkuiMenu {

class Palette {
    Q_GADGET
public:
    // Warning 警告: 谨防 qt版本更新后，删除，增加或者调整调色板的枚举值
    enum ColorGroup {
        Active, Disabled, Inactive
    };

    Q_ENUM(ColorGroup)

    enum ColorRole {
        Window, WindowText, Base, Text, AlternateBase,
        Button, ButtonText, Light, MidLight, Dark, Mid, Shadow,
        Highlight, HighlightedText
    };

    Q_ENUM(ColorRole)
};

class ThemePalette : public QObject {
    Q_OBJECT
public:
    static ThemePalette *getInstance();

    /**
     * 根据调色板的枚举值，获取主题调色板的颜色
     * @param colorRole
     * @return
     */
    Q_INVOKABLE QColor
    paletteColor(Palette::ColorRole colorRole, Palette::ColorGroup colorGroup = Palette::Active) const;

    /**
     * 获取自定义透明度的颜色
     * @param colorRole
     * @return
     */
    Q_INVOKABLE QColor
    paletteColorWithCustomTransparency(Palette::ColorRole colorRole, Palette::ColorGroup colorGroup,
                                       qreal alphaF) const;

    /**
     * 获取带有主题透明度的颜色
     * @param colorRole
     * @return
     */
    Q_INVOKABLE QColor paletteColorWithTransparency(Palette::ColorRole colorRole,
                                                    Palette::ColorGroup colorGroup = Palette::Active) const;

    Q_INVOKABLE QColor window(Palette::ColorGroup colorGroup = Palette::Active) const;
    Q_INVOKABLE QColor windowText(Palette::ColorGroup colorGroup = Palette::Active) const;
    Q_INVOKABLE QColor base(Palette::ColorGroup colorGroup = Palette::Active) const;
    Q_INVOKABLE QColor text(Palette::ColorGroup colorGroup = Palette::Active) const;
    Q_INVOKABLE QColor alternateBase(Palette::ColorGroup colorGroup = Palette::Active) const;
    Q_INVOKABLE QColor button(Palette::ColorGroup colorGroup = Palette::Active) const;
    Q_INVOKABLE QColor buttonText(Palette::ColorGroup colorGroup = Palette::Active) const;
    Q_INVOKABLE QColor light(Palette::ColorGroup colorGroup = Palette::Active) const;
    Q_INVOKABLE QColor midLight(Palette::ColorGroup colorGroup = Palette::Active) const;
    Q_INVOKABLE QColor dark(Palette::ColorGroup colorGroup = Palette::Active) const;
    Q_INVOKABLE QColor mid(Palette::ColorGroup colorGroup = Palette::Active) const;
    Q_INVOKABLE QColor shadow(Palette::ColorGroup colorGroup = Palette::Active) const;
    Q_INVOKABLE QColor highlight(Palette::ColorGroup colorGroup = Palette::Active) const;
    Q_INVOKABLE QColor highlightedText(Palette::ColorGroup colorGroup = Palette::Active) const;
    Q_INVOKABLE QColor separator(Palette::ColorGroup colorGroup = Palette::Active) const;

Q_SIGNALS:
    void styleColorChanged();

private Q_SLOTS:
    void styleChangedSlot(const GlobalSetting::Key& key);

private:
    explicit ThemePalette(QObject *parent = nullptr);
    static QPalette::ColorGroup switchColorGroup(Palette::ColorGroup colorGroup);
    void initStyleSetting();

private:
    qreal m_transparency = 1.0;
};

}

#endif //UKUI_SIDEBAR_THEME_PALETTE_H
