/*
 * Copyright (C) 2022, KylinSoft Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

#ifndef UKUI_MENU_UKUI_MENU_APPLICATION_H
#define UKUI_MENU_UKUI_MENU_APPLICATION_H

#include <QObject>

class QQmlEngine;
class QCommandLineOption;

namespace UkuiMenu {

class MenuMessageProcessor;
class MenuWindow;
class MenuDbusService;

class UkuiMenuApplication : public QObject
{
    Q_OBJECT
public:
    enum Command {
        Active = 0,
        Show,
        Quit,
        Hide
    };
    explicit UkuiMenuApplication(MenuMessageProcessor *processor);
    ~UkuiMenuApplication() override;
    UkuiMenuApplication() = delete;
    UkuiMenuApplication(const UkuiMenuApplication& obj) = delete;
    UkuiMenuApplication(const UkuiMenuApplication&& obj) = delete;

private Q_SLOTS:
    void execCommand(UkuiMenuApplication::Command command);

private:
    static void registerQmlTypes();
    void startUkuiMenu();
    void initQmlEngine();
    void loadMenuUI();

    //注册dubs
    void initDbusService();

private:
    QQmlEngine *m_engine{nullptr};
    MenuWindow *m_mainWindow{nullptr};
    MenuDbusService *m_menuDbusService{nullptr};
};

class MenuMessageProcessor : public QObject
{
    Q_OBJECT
public:
    MenuMessageProcessor();
    static bool preprocessMessage(const QStringList& message);
    static QCommandLineOption showUkuiMenu;
    static QCommandLineOption quitUkuiMenu;

public Q_SLOTS:
    void processMessage(const QString &message);

Q_SIGNALS:
    void request(UkuiMenuApplication::Command command);
};

//2023-06-01 add by fyl 
//添加一个获取cpu信息的类
//目前用于设置开始菜单，滚轮的速度
//后续可考虑扩展应用
class CpuInfo : public QObject
{
    Q_OBJECT
    //qt参数映射
    Q_PROPERTY(int wheelSpeed READ getWheelSpeed)
public:
    //构造时，获取cpu信息
    CpuInfo();

    //注册qml载入类型
    static void defineModule(const char *uri, int versionMajor, int versionMinor);
    //获取速率
    int getWheelSpeed();
private:
    //获取cpu类型和核心数量
    void getCupInfo();
    //读取速度配置信息
    void readSettings();
private:
    QString m_cupType;//cpu型号
    int m_coreCount;//cpu核心数量

    int m_normalSpeed;//默认速率
    int m_lowSpeed;//针对E2000的低速率
    int m_highSpeed;//高速率（20230601 暂未应用）
};

}

#endif //UKUI_MENU_UKUI_MENU_APPLICATION_H
